import { jsx as _jsx } from "react/jsx-runtime";
import { useEffect, useLayoutEffect, useRef } from 'react';
import { useCommentStateContext } from '../contexts/CommentStateContext';
const CommentPosition = ({ commentId, children, }) => {
    var _a, _b;
    const { state, dispatch, recalculatePositions, commentPositions } = useCommentStateContext();
    const { commentsSectionOffsetY, activeCommentId } = state;
    const commentRef = useRef(null);
    // State to track whether the initial positioning has occurred
    const hasPositionedRef = useRef(false);
    const updateHeightAndRecalculate = () => {
        if (!commentRef.current)
            return;
        const height = commentRef.current.getBoundingClientRect().height;
        dispatch({
            type: 'UPDATE_COMMENT_HEIGHT',
            payload: { id: commentId, height },
        });
        recalculatePositions();
    };
    // Measure initial height
    useLayoutEffect(() => {
        updateHeightAndRecalculate();
    }, []);
    // Monitor dynamic height changes
    useLayoutEffect(() => {
        if (!commentRef.current)
            return;
        const resizeObserver = new ResizeObserver(() => {
            updateHeightAndRecalculate();
        });
        resizeObserver.observe(commentRef.current);
        return () => {
            resizeObserver.disconnect();
        };
    }, []);
    useEffect(() => {
        if (!commentRef.current)
            return;
        const element = commentRef.current;
        const handleClick = (e) => {
            const target = e.target;
            // Don't focus the parent container if user clicked on:
            // - Buttons: Have their own focus and click behavior
            // - Links: Need to handle navigation
            // - Inputs/Textareas: Need to handle text entry
            // - Custom buttons: Elements with role="button" (like div styled as button)
            const interactiveTags = ['BUTTON', 'A', 'INPUT', 'TEXTAREA'];
            if (interactiveTags.includes(target.tagName) ||
                // closest() checks if the clicked element or any of its parents have role="button"
                // This catches custom button implementations that don't use <button> tags
                target.closest('[role="button"]'))
                return;
            element.focus();
        };
        element.addEventListener('click', handleClick);
        return () => {
            element.removeEventListener('click', handleClick);
        };
    }, []);
    const onDeleteSuccess = () => {
        dispatch({ type: 'DELETE_COMMENT', payload: { id: commentId } });
    };
    const onFocus = () => {
        dispatch({ type: 'SET_ACTIVE_COMMENT_ID', payload: commentId });
    };
    // Position off-screen when position is unknown
    const adjustedTop = (_b = (_a = commentPositions[commentId]) === null || _a === void 0 ? void 0 : _a.top) !== null && _b !== void 0 ? _b : -9999;
    useEffect(() => {
        if (adjustedTop !== -9999 && !hasPositionedRef.current)
            hasPositionedRef.current = true;
    }, [adjustedTop]);
    const shouldTransition = hasPositionedRef.current;
    const isOffScreen = adjustedTop === -9999;
    return (_jsx("div", { ref: commentRef, tabIndex: isOffScreen ? -1 : 0, style: {
            position: 'absolute',
            top: `${adjustedTop - commentsSectionOffsetY}px`,
            transition: shouldTransition ? 'top 0.3s ease-out' : 'none',
            left: 0,
            width: '100%',
            pointerEvents: isOffScreen ? 'none' : 'auto',
        }, onFocus: onFocus, "aria-hidden": isOffScreen, children: typeof children === 'function'
            ? children({
                isActive: activeCommentId === commentId,
                onDeleteSuccess,
            })
            : children }));
};
export default CommentPosition;
//# sourceMappingURL=CommentPosition.js.map