import { jsx as _jsx } from "react/jsx-runtime";
import { debounce } from 'lodash';
import { useCallback, useEffect, useRef } from 'react';
import { useAnchoredCommentsContext } from '../contexts/AnchoredCommentsContext';
const CommentSection = ({ children, }) => {
    const sectionRef = useRef(null);
    const { state, dispatch } = useAnchoredCommentsContext();
    const { activeCommentId } = state;
    const setOffset = useCallback(() => {
        if (!sectionRef.current)
            return;
        const offset = sectionRef.current.getBoundingClientRect().top + window.scrollY;
        dispatch({
            type: 'UPDATE_COMMENT_SECTION_OFFSETY',
            payload: offset,
        });
    }, [dispatch]);
    useEffect(() => {
        // Initial call to set offset
        setOffset();
        const debouncedHandleResize = debounce(setOffset, 250);
        window.addEventListener('resize', debouncedHandleResize);
        return () => {
            window.removeEventListener('resize', debouncedHandleResize);
            debouncedHandleResize.cancel(); // Cancel any pending debounced calls
        };
    }, [setOffset]);
    return (_jsx("div", { ref: sectionRef, style: { position: 'relative' }, children: typeof children === 'function'
            ? children({
                activeCommentId,
            })
            : children }));
};
export default CommentSection;
//# sourceMappingURL=CommentSection.js.map