import { jsx as _jsx } from "react/jsx-runtime";
import { createContext, useCallback, useContext, useEffect, useMemo, useState, } from 'react';
import { calculatePositions } from '../utils/calculatePositions';
import { useSelectionContext } from './SelectionContext';
const CommentPositionContext = createContext(undefined);
export const CommentPositionProvider = ({ children, }) => {
    const [visibleComments, setVisibleComments] = useState(new Set());
    const [commentSizes, setCommentSizes] = useState({});
    const [adjustedPositions, setAdjustedPositions] = useState({});
    const { commentPositionState } = useSelectionContext();
    // TODO: fix the memoization here - positions get calculated on every render
    const updatePositions = useCallback(() => {
        const newPositions = calculatePositions(commentPositionState, visibleComments, commentSizes);
        setAdjustedPositions(newPositions);
    }, [commentPositionState, visibleComments, commentSizes]);
    useEffect(() => {
        updatePositions();
    }, [updatePositions]);
    const registerComment = useCallback((id) => {
        setVisibleComments(prev => new Set(prev).add(id));
    }, []);
    const unregisterComment = useCallback((id) => {
        setVisibleComments(prev => {
            const newSet = new Set(prev);
            newSet.delete(id);
            return newSet;
        });
        setCommentSizes(prev => {
            const newSizes = Object.assign({}, prev);
            delete newSizes[id];
            return newSizes;
        });
    }, []);
    const updateCommentSize = useCallback((id, size) => {
        setCommentSizes(prev => {
            if (JSON.stringify(prev[id]) !== JSON.stringify(size)) {
                return Object.assign(Object.assign({}, prev), { [id]: size });
            }
            return prev;
        });
    }, []);
    const getAdjustedTop = useCallback((id) => {
        var _a, _b, _c, _d;
        return (_d = (_b = (_a = adjustedPositions[id]) === null || _a === void 0 ? void 0 : _a.top) !== null && _b !== void 0 ? _b : (_c = commentPositionState.positions[id]) === null || _c === void 0 ? void 0 : _c.top) !== null && _d !== void 0 ? _d : 0;
    }, [adjustedPositions, commentPositionState]);
    const contextValue = useMemo(() => ({
        registerComment,
        unregisterComment,
        getAdjustedTop,
        updateCommentSize,
    }), [
        registerComment,
        unregisterComment,
        getAdjustedTop,
        updateCommentSize,
    ]);
    return (_jsx(CommentPositionContext.Provider, { value: contextValue, children: children }));
};
export const useCommentPositionContext = () => {
    const context = useContext(CommentPositionContext);
    if (!context) {
        throw new Error('useCommentPositionContext must be used within a CommentPositionProvider');
    }
    return context;
};
//# sourceMappingURL=CommentPositionContext.js.map