import React, { ReactNode } from 'react';
import type { Comment } from '../types';
import { PositionedSelectionRange, Positions } from '../types';
export type CommentState = {
    commentableSectionOffsetY: number;
    commentsSectionOffsetY: number;
    activeCommentId: string | null;
    textPositions: Positions;
    commentHeights: Record<string, number>;
    selection: PositionedSelectionRange | null;
    newComment: {
        id: string;
        selectionRange: PositionedSelectionRange;
        height?: number;
    } | null;
    comments: Comment[];
};
export type CommentAction = {
    type: 'SET_ACTIVE_COMMENT_ID';
    payload: string | null;
} | {
    type: 'SET_SELECTION';
    payload: PositionedSelectionRange | null;
} | {
    type: 'SET_ACTIVE_COMMENT_AND_SELECTION';
    payload: {
        activeCommentId: string | null;
        selection: PositionedSelectionRange | null;
    };
} | {
    type: 'SHOW_NEW_COMMENT_BOX';
} | {
    type: 'CANCEL_NEW_COMMENT';
} | {
    type: 'UPDATE_COMMENT_HEIGHT';
    payload: {
        id: string;
        height: number;
    };
} | {
    type: 'UPDATE_TEXT_POSITIONS';
    payload: Record<string, {
        top: number;
    }>;
} | {
    type: 'UPDATE_COMMENTABLE_SECTION_OFFSETY';
    payload: number;
} | {
    type: 'UPDATE_COMMENTS_SECTION_OFFSETY';
    payload: number;
} | {
    type: 'ADD_COMMENT';
    payload: Comment;
} | {
    type: 'DELETE_COMMENT';
    payload: {
        id: string;
    };
};
type CommentStateContextType = {
    state: CommentState;
    dispatch: React.Dispatch<CommentAction>;
    commentableContainers: React.MutableRefObject<Partial<Record<string, React.RefObject<HTMLDivElement>>>>;
    commentPositions: Positions;
    recalculatePositions: () => void;
};
export declare const CommentStateProvider: ({ initialComments, children, }: {
    initialComments: Comment[];
    children: ReactNode;
}) => import("react/jsx-runtime").JSX.Element;
export declare const useCommentStateContext: () => CommentStateContextType;
export {};
