import { jsx as _jsx } from "react/jsx-runtime";
import { createContext, useCallback, useContext, useReducer, useRef, useState, } from 'react';
import { commentReducer } from '../reducers/commentReducer';
import { calculatePositions } from '../utils/calculatePositions';
const CommentStateContext = createContext(null);
export const CommentStateProvider = ({ initialComments, children, }) => {
    const [state, dispatch] = useReducer(commentReducer, {
        commentableSectionOffsetY: 0,
        commentsSectionOffsetY: 0,
        activeCommentId: null,
        textPositions: {},
        commentHeights: {},
        selection: null,
        newComment: null,
        comments: initialComments,
    });
    const commentableContainers = useRef({});
    const [commentPositions, setCommentPositions] = useState({});
    const recalculatePositions = useCallback(() => {
        const textPositionsWithNewComment = Object.assign(Object.assign({}, state.textPositions), (state.newComment && {
            [state.newComment.id]: {
                top: state.newComment.selectionRange.positionTop,
            },
        }));
        const visibleComments = new Set([
            ...state.comments.map(comment => comment.id),
            ...(state.newComment ? [state.newComment.id] : []),
        ]);
        const positions = calculatePositions(textPositionsWithNewComment, state.activeCommentId, visibleComments, state.commentHeights);
        setCommentPositions(positions);
    }, [state]);
    return (_jsx(CommentStateContext.Provider, { value: {
            state,
            dispatch,
            commentableContainers,
            commentPositions,
            recalculatePositions,
        }, children: children }));
};
export const useCommentStateContext = () => {
    const context = useContext(CommentStateContext);
    if (!context) {
        throw new Error('useCommentStateContext must be used within a CommentStateProvider');
    }
    return context;
};
//# sourceMappingURL=CommentStateContext.js.map