import { jsx as _jsx } from "react/jsx-runtime";
import { createContext, useCallback, useContext, useMemo, useState, } from 'react';
function createCommentContext() {
    const CommentContext = createContext(undefined);
    const useCommentContext = () => {
        const context = useContext(CommentContext);
        if (context === undefined) {
            throw new Error('useCommentContext must be used within a CommentProvider');
        }
        return context;
    };
    const CommentProvider = ({ children, initialComments, }) => {
        const [comments, setComments] = useState(initialComments);
        const addComment = useCallback((comment) => {
            setComments(prevComments => [...prevComments, comment]);
        }, [setComments]);
        const deleteComment = useCallback((commentId) => {
            setComments(prevComments => prevComments.filter(c => c.id !== commentId));
        }, [setComments]);
        const value = useMemo(() => ({
            comments,
            setComments,
            addComment,
            deleteComment,
        }), [comments, setComments, addComment, deleteComment]);
        return (_jsx(CommentContext.Provider, { value: value, children: children }));
    };
    return { useCommentContext, CommentProvider };
}
export { createCommentContext };
//# sourceMappingURL=createCommentContext.js.map