import { jsx as _jsx } from "react/jsx-runtime";
import { createContext, useCallback, useContext, useMemo, useState, } from 'react';
function createCommentsContext() {
    const CommentsContext = createContext(undefined);
    const useCommentsContext = () => {
        const context = useContext(CommentsContext);
        if (context === undefined) {
            throw new Error('useCommentsContext must be used within a CommentsProvider');
        }
        return context;
    };
    const CommentsProvider = ({ children, initialComments, }) => {
        const [comments, setComments] = useState(initialComments);
        const addComment = useCallback((comment) => {
            setComments(prevComments => [...prevComments, comment]);
        }, [setComments]);
        const deleteComment = useCallback((commentId) => {
            setComments(prevComments => prevComments.filter(c => c.id !== commentId));
        }, [setComments]);
        const value = useMemo(() => ({
            comments,
            setComments,
            addComment,
            deleteComment,
        }), [comments, setComments, addComment, deleteComment]);
        return (_jsx(CommentsContext.Provider, { value: value, children: children }));
    };
    return { useCommentsContext, CommentsProvider };
}
export { createCommentsContext };
//# sourceMappingURL=createCommentsContext.js.map